"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var models_1 = require("../../models");
var symbologies_1 = require("../../config/symbologies");
describe('BarcodeValue', function () {
    var classUnderTest;
    var symbology = 'MYSYMBOLOGY';
    var rawVal = '123456';
    beforeEach(function () {
        classUnderTest = new models_1.BarcodeValue(symbology, rawVal);
    });
    test('should set symbology', function () {
        expect(classUnderTest.symbology).toBe(symbology);
    });
    test('should set rawValue', function () {
        expect(classUnderTest.rawValue).toBe(rawVal);
    });
    test('isWeightBased should be true for GTIN13', function () {
        classUnderTest = new models_1.BarcodeValue(symbologies_1.Symbologies.GTIN13, '');
        classUnderTest.values = '2843970021365';
        expect(classUnderTest.isWeightBased).toBeTruthy();
    });
    test('isWeightBased should be false for other Systems', function () {
        classUnderTest = new models_1.BarcodeValue(symbologies_1.Symbologies.GTIN13, '');
        classUnderTest.values = '3843970021365';
        expect(classUnderTest.isWeightBased).toBeFalsy();
    });
    test('systemId should return first half value', function () {
        classUnderTest = new models_1.BarcodeValue(symbologies_1.Symbologies.GTIN13, '');
        classUnderTest.values = '2843970021365';
        expect(classUnderTest.systemId).toEqual('84397');
    });
    test('systemValue should return second half value', function () {
        classUnderTest = new models_1.BarcodeValue(symbologies_1.Symbologies.GTIN13, '');
        classUnderTest.values = '2843970021365';
        expect(classUnderTest.systemMeasure).toEqual(21.36);
    });
    describe('pluck', function () {
        test('return values of existing keys', function () {
            classUnderTest.values = [
                {
                    code: '01',
                    value: 'abcd',
                },
            ];
            expect(classUnderTest.pluck('01')).toBe('abcd');
        });
        test('should return undefined for non-existant keys', function () {
            classUnderTest.values = [
                {
                    code: '01',
                    value: 'abcd',
                },
            ];
            expect(classUnderTest.pluck('04')).toBeUndefined();
        });
        test('should return undefined for non-array values', function () {
            classUnderTest.values = 'i am a string';
            expect(classUnderTest.pluck('04')).toBeUndefined();
        });
    });
});
//# sourceMappingURL=barcode-value.spec.js.map